@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,8 +23,9 @@
 
 #include <KCupsRequest.h>
 
-#include <QStringBuilder>
-#include <QDebug>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(PM_ADD_PRINTER)
 
 ChooseUri::ChooseUri(QWidget *parent) :
     GenericPage(parent),
@@ -32,7 +33,7 @@ ChooseUri::ChooseUri(QWidget *parent) :
 {
     ui->setupUi(this);
 
-    ui->searchTB->setIcon(QIcon::fromTheme("edit-find"));
+    ui->searchTB->setIcon(QIcon::fromTheme(QLatin1String("edit-find")));
 
     // setup default options
     setWindowTitle(i18nc("@title:window", "Select a Printer to Add"));
@@ -51,12 +52,12 @@ void ChooseUri::setValues(const QVariantHash &args)
 {
     m_args = args;
     bool visible = false;
-    QUrl url(args[KCUPS_DEVICE_URI].toString());
+    const QUrl url(args[KCUPS_DEVICE_URI].toString());
     if (url.url() == QLatin1String("other")) {
         ui->addressLE->clear();
         visible = true;
     } else if (url.scheme().isEmpty() && url.authority().isEmpty()) {
-        ui->addressLE->setText(url.url() % QLatin1String("://"));
+        ui->addressLE->setText(url.url() + QLatin1String("://"));
     } else {
         ui->addressLE->setText(url.url());
     }
@@ -68,17 +69,20 @@ QVariantHash ChooseUri::values() const
 {
     QVariantHash ret = m_args;
 
-    ret[KCUPS_DEVICE_URI] = parsedURL(ui->addressLE->text()).url();
+    ret[KCUPS_DEVICE_URI] = parsedURL(ui->addressLE->text()).toString();
 
     return ret;
 }
 
 bool ChooseUri::isValid() const
 {
-    QVariantHash args = values();
-    QUrl url(args[KCUPS_DEVICE_URI].toString());
-    //qDebug() << url << url.isValid() << url.isEmpty() << url.scheme().isEmpty() << url.host();
-    return url.isValid() && !url.isEmpty() && !url.scheme().isEmpty() && !url.host().isEmpty();
+    const QString urlDefault = m_args[KCUPS_DEVICE_URI].toString();
+    const QVariantHash args = values();
+    const QString deviceUri = args[KCUPS_DEVICE_URI].toString();
+    QUrl url(deviceUri);
+//    qCDebug(PM_ADD_PRINTER) << url << url.isValid() << url.isEmpty() << url.scheme().isEmpty() << url.host() << url.toString();
+    return (url.isValid() && !url.isEmpty() && !url.scheme().isEmpty() && !url.host().isEmpty())
+            || urlDefault == deviceUri;
 }
 
 bool ChooseUri::canProceed() const
@@ -101,9 +105,9 @@ void ChooseUri::on_addressLE_textChanged(const QString &text)
 
     if (url.isValid() &&
             (url.scheme().isEmpty() ||
-             url.scheme() == QStringLiteral("http") ||
-             url.scheme() == QStringLiteral("https") ||
-             url.scheme() == QStringLiteral("ipp"))) {
+             url.scheme() == QLatin1String("http") ||
+             url.scheme() == QLatin1String("https") ||
+             url.scheme() == QLatin1String("ipp"))) {
         // TODO maybe cups library can connect to more protocols
         ui->searchTB->setEnabled(true);
     } else {
@@ -113,30 +117,29 @@ void ChooseUri::on_addressLE_textChanged(const QString &text)
 
 void ChooseUri::findPrinters()
 {
-    QUrl url = parsedURL(ui->addressLE->text());
+    const QUrl url = parsedURL(ui->addressLE->text());
 
-    KCupsConnection *conn = new KCupsConnection(url, this);
-    KCupsRequest *request = new KCupsRequest(conn);
+    auto conn = new KCupsConnection(url, this);
+    auto request = new KCupsRequest(conn);
     connect(request, &KCupsRequest::finished, this, &ChooseUri::getPrintersFinished);
 
-    QStringList attr;
-    attr << KCUPS_PRINTER_NAME;
-    attr << KCUPS_PRINTER_STATE;
-    attr << KCUPS_PRINTER_IS_SHARED;
-    attr << KCUPS_PRINTER_IS_ACCEPTING_JOBS;
-    attr << KCUPS_PRINTER_TYPE;
-    attr << KCUPS_PRINTER_LOCATION;
-    attr << KCUPS_PRINTER_INFO;
-    attr << KCUPS_PRINTER_MAKE_AND_MODEL;
     request->setProperty("URI", url);
 
     emit startWorking();
-    request->getPrinters(attr);
+    request->getPrinters({
+                             KCUPS_PRINTER_NAME,
+                             KCUPS_PRINTER_STATE,
+                             KCUPS_PRINTER_IS_SHARED,
+                             KCUPS_PRINTER_IS_ACCEPTING_JOBS,
+                             KCUPS_PRINTER_TYPE,
+                             KCUPS_PRINTER_LOCATION,
+                             KCUPS_PRINTER_INFO,
+                             KCUPS_PRINTER_MAKE_AND_MODEL
+                         });
 }
 
-void ChooseUri::getPrintersFinished()
+void ChooseUri::getPrintersFinished(KCupsRequest *request)
 {
-    KCupsRequest *request = qobject_cast<KCupsRequest*>(sender());
     QUrl uri = request->property("URI").value<QUrl>();
     QUrl url;
     url.setScheme(QStringLiteral("ipp"));
@@ -146,7 +149,7 @@ void ChooseUri::getPrintersFinished()
     if (request->hasError()) {
         emit errorMessage(request->errorMsg());
     } else {
-        emit insertDevice("network",
+        emit insertDevice(QLatin1String("network"),
                           url.authority(),
                           url.authority(),
                           QString(),
@@ -162,8 +165,9 @@ void ChooseUri::getPrintersFinished()
 
 QUrl ChooseUri::parsedURL(const QString &text) const
 {
+    const QString urlDefault = m_args[KCUPS_DEVICE_URI].toString();
     QUrl url(QUrl::fromUserInput(text));
-    if (url.host().isEmpty() && !text.contains(QLatin1String("://"))) {
+    if (url.host().isEmpty() && !text.contains(QLatin1String("://")) && urlDefault != text) {
         url = QUrl();
         // URI might be scsi, network on anything that didn't match before
         if (m_args[KCUPS_DEVICE_URI].toString() != QLatin1String("other")) {
@@ -173,3 +177,5 @@ QUrl ChooseUri::parsedURL(const QString &text) const
     }
     return url;
 }
+
+#include "moc_ChooseUri.cpp"
