@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,6 +25,7 @@
 
 #include <QPainter>
 #include <QPointer>
+#include <QRegExpValidator>
 #include <QDebug>
 
 #include <KIconLoader>
@@ -40,14 +41,14 @@ PageAddPrinter::PageAddPrinter(QWidget *parent) :
     setWindowTitle(i18nc("@title:window", "Select a Printer to Add"));
     // loads the standard key icon
     QPixmap pixmap;
-    pixmap = KIconLoader::global()->loadIcon("printer",
+    pixmap = KIconLoader::global()->loadIcon(QLatin1String("printer"),
                                              KIconLoader::NoGroup,
                                              KIconLoader::SizeEnormous, // a not so huge icon
                                              KIconLoader::DefaultState);
     QPixmap icon(pixmap);
     QPainter painter(&icon);
 
-    pixmap = KIconLoader::global()->loadIcon("dialog-information",
+    pixmap = KIconLoader::global()->loadIcon(QLatin1String("dialog-information"),
                                              KIconLoader::NoGroup,
                                              KIconLoader::SizeLarge, // a not so huge icon
                                              KIconLoader::DefaultState);
@@ -61,11 +62,12 @@ PageAddPrinter::PageAddPrinter(QWidget *parent) :
     ui->printerL->setPixmap(icon);
 
     // May contain any printable characters except "/", "#", and space
-    QRegExp rx("[^/#\\ ]*");
-    QValidator *validator = new QRegExpValidator(rx, this);
+    QRegExp rx(QLatin1String("[^/#\\ ]*"));
+    auto validator = new QRegExpValidator(rx, this);
     ui->nameLE->setValidator(validator);
 
     // Hide the message widget
+    ui->messageWidget->setWordWrap(true);
     ui->messageWidget->setMessageType(KMessageWidget::Error);
     ui->messageWidget->hide();
 }
@@ -174,3 +176,5 @@ void PageAddPrinter::checkSelected()
 {
 //     emit allowProceed(!devicesLV->selectionModel()->selection().isEmpty());
 }
+
+#include "moc_PageAddPrinter.cpp"
