@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,15 +28,13 @@
 
 #include <QFileInfo>
 #include <QFile>
-#include <QStringBuilder>
 #include <QDebug>
 #include <QUrl>
 #include <QTemporaryFile>
 
 PageChoosePPD::PageChoosePPD(const QVariantHash &args, QWidget *parent) :
     GenericPage(parent),
-    ui(new Ui::PageChoosePPD),
-    m_isValid(false)
+    ui(new Ui::PageChoosePPD)
 {
     ui->setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
@@ -82,12 +80,12 @@ void PageChoosePPD::setValues(const QVariantHash &args)
         QString deviceURI = args[KCUPS_DEVICE_URI].toString();
 
         // If
-        QUrl url(deviceURI % QStringLiteral(".ppd"));
-        if (url.scheme() == QStringLiteral("ipp")) {
-            QTemporaryFile *tempFile = new QTemporaryFile;
-            tempFile->setFileTemplate(QStringLiteral("print-manager-XXXXXX.ppd"));
+        QUrl url(deviceURI + QLatin1String(".ppd"));
+        if (url.scheme() == QLatin1String("ipp")) {
+            auto tempFile = new QTemporaryFile;
+            tempFile->setFileTemplate(QLatin1String("print-manager-XXXXXX.ppd"));
             tempFile->open();
-            url.setScheme(QStringLiteral("http"));
+            url.setScheme(QLatin1String("http"));
             if (url.port() < 0) {
                 url.setPort(631);
             }
@@ -101,8 +99,8 @@ void PageChoosePPD::setValues(const QVariantHash &args)
         }
 
         // Get the make from the device id
-        foreach (const QString &pair, deviceId.split(QLatin1Char(';'))) {
-            if (pair.startsWith(QStringLiteral("MFG:"))) {
+        for (const QString &pair : deviceId.split(QLatin1Char(';'))) {
+            if (pair.startsWith(QLatin1String("MFG:"))) {
                 make = pair.section(QLatin1Char(':'), 1);
                 break;
             }
@@ -110,13 +108,13 @@ void PageChoosePPD::setValues(const QVariantHash &args)
 
         if (makeAndModel.isEmpty()) {
             // Get the model  from the device id
-            foreach (const QString &pair, deviceId.split(QLatin1Char(';'))) {
-                if (pair.startsWith(QStringLiteral("MDL:"))) {
+            for (const QString &pair : deviceId.split(QLatin1Char(';'))) {
+                if (pair.startsWith(QLatin1String("MDL:"))) {
                     // Build the make and model string
                     if (make.isNull()) {
                         makeAndModel = pair.section(QLatin1Char(':'), 1);
                     } else {
-                        makeAndModel = make % QLatin1Char(' ') % pair.section(QLatin1Char(':'), 1);
+                        makeAndModel = make + QLatin1Char(' ') + pair.section(QLatin1Char(':'), 1);
                     }
                     break;
                 }
@@ -189,7 +187,7 @@ void PageChoosePPD::selectDefault()
 void PageChoosePPD::resultJob(KJob *job)
 {
     if (!job->error() && job->property("URI").toString() == m_args[KCUPS_DEVICE_URI].toString()) {
-        KIO::FileCopyJob *fileCopyJob = qobject_cast<KIO::FileCopyJob*>(job);
+        auto fileCopyJob = qobject_cast<KIO::FileCopyJob*>(job);
 
         // Make sure this job is for the current device
         m_ppdFile = fileCopyJob->destUrl().toLocalFile();
@@ -205,3 +203,5 @@ void PageChoosePPD::removeTempPPD()
         m_ppdFile.clear();
     }
 }
+
+#include "moc_PageChoosePPD.cpp"
